@@ -1183,7 +1183,8 @@ def process_tsv(fn):
 			try:
 				what = vocabData[info[6]]
 			except:
-				what = vocabData["rdf:Resource"]
+				print("Failed to find class for %s given %s" % (data, info[6]))
+				raise
 			what["props"].append(data)
 
 			koh = int(info[9])
@@ -1206,6 +1207,7 @@ def process_tsv(fn):
 
 # Build class heirarchy recursively
 def build_class(crmName, parent, vocabData):
+
 	data = vocabData[crmName]
 	name = str(data['className'])
 
@@ -1272,6 +1274,7 @@ def build_class(crmName, parent, vocabData):
 
 def build_classes(fn=None, topClass=None):
 	# Default to building our core dataset
+
 	if not fn:
 		dd = os.path.join(os.path.dirname(__file__), 'data')
 		fn = os.path.join(dd, 'crm_vocab.tsv')
@@ -1303,6 +1306,9 @@ def build_classes(fn=None, topClass=None):
 			else:
 				rng = rngd['class']
 				# and add inverse prop name from range
+				if rng == None:
+					# Uh-oh!
+					raise ConfigurationError("Class %s did not get built, range of %s" % (value['rangeStr'], name))
 				for (ik, iv) in rng._properties.items():
 					if iv['inverseRdf'] == value['rdf']:
 						inverse = ik
